@@ -3,7 +3,7 @@ from requests.packages.urllib3.exceptions import InsecureRequestWarning
 
 
 class Authentication:
-    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=2):
+    def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=7, debug=True, otp_code=None):
         self._ip_address = ip_address
         self._port = port
         self._username = username
@@ -12,6 +12,8 @@ class Authentication:
         self._session_expire = True
         self._verify = cert_verify
         self._version = dsm_version
+        self._debug = debug
+        self._otp_code = otp_code
         if self._verify is False:
             requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
         schema = 'https' if secure else 'http'
@@ -27,16 +29,20 @@ class Authentication:
         login_api = 'auth.cgi?api=SYNO.API.Auth'
         param = {'version': self._version, 'method': 'login', 'account': self._username,
                  'passwd': self._password, 'session': application, 'format': 'cookie'}
+        if self._otp_code:
+            param['otp_code'] = self._otp_code
 
         if not self._session_expire:
             if self._sid is not None:
                 self._session_expire = False
-                return 'User already logged'
+                if self._debug is True:
+                    return 'User already logged'
         else:
             session_request = requests.get(self._base_url + login_api, param, verify=self._verify)
             self._sid = session_request.json()['data']['sid']
             self._session_expire = False
-            return 'User logging... New session started!'
+            if self._debug is True:
+                return 'User logging... New session started!'
 
     def logout(self, application):
         logout_api = 'auth.cgi?api=SYNO.API.Auth'
@@ -46,11 +52,13 @@ class Authentication:
         if response.json()['success'] is True:
             self._session_expire = True
             self._sid = None
-            return 'Logged out'
+            if self._debug is True:
+                return 'Logged out'
         else:
             self._session_expire = True
             self._sid = None
-            return 'No valid session is open'
+            if self._debug is True:
+                return 'No valid session is open'
 
     def get_api_list(self, app=None):
         query_path = 'query.cgi?api=SYNO.API.Info'
@@ -106,7 +114,7 @@ class Authentication:
 
         req_param['_sid'] = self._sid
 
-        if method is 'get':
+        if method == 'get':
             url = ('%s%s' % (self._base_url, api_path)) + '?api=' + api_name
             response = requests.get(url, req_param, verify=self._verify)
 
@@ -115,7 +123,7 @@ class Authentication:
             else:
                 return response
 
-        elif method is 'post':
+        elif method == 'post':
             url = ('%s%s' % (self._base_url, api_path)) + '?api=' + api_name
             response = requests.post(url, req_param, verify=self._verify)
 
